@@ -2,11 +2,14 @@
 #' @importFrom utils head tail 
 #' @importFrom graphics par axis title plot rect legend
 #' @importFrom mhsmm simulate.hmmspec hmmspec dnorm.hsmm rnorm.hsmm
-#' @importFrom zoo rollmean rollsum rollmedian
 #' @importFrom PhysicalActivity dataCollapser
+#' @importFrom Rcpp evalCpp
+#' @useDynLib acc
+
 acc <- function(data, tri='FALSE', axis=NULL,
                 spuriousDef=20, nonwearDef=60, minWear=600, 
                 patype=c('Sedentary','MVPA'),pacut=c(c(0,99),c(1952,Inf)), 
+                epoch=c('1 min','1 min'),
                 boutsize=c(10,10), tolerance=c('FALSE','TRUE')){
   
   summaryByPA <- list() 
@@ -16,7 +19,7 @@ acc <- function(data, tri='FALSE', axis=NULL,
       summaryByPA[[patype[i]]] <- accSummary(data=data, tri=tri, axis=axis,
                                              spuriousDef=spuriousDef, 
                                              nonwearDef=nonwearDef, minWear=minWear, 
-                                             patype=patype[i],
+                                             patype=patype[i],epoch=epoch[i],
                                              pacut=c(pacut[seq(1, length(pacut), 2)][i],pacut[seq(2, length(pacut), 2)][i]), 
                                              boutsize=boutsize[i], tolerance=tolerance[i],returnbout='FALSE')
     }
