@@ -4,22 +4,22 @@
 #' @importFrom nleqslv nleqslv
 #' @importFrom stats model.matrix
 #' @importFrom methods getClass
-
+#' @importFrom Rcpp evalCpp
+#' @useDynLib acc
 
 
 ##############################################################################
 # User's Main Function
 ##############################################################################
-aeefit <- function(formula, data, weight=NULL, control=list()) {
+aeefit <- function(formula, data, weight=NULL, se="Sandwich", control=list(), boot=NULL) {
   
   method <- "AEE"
-  se <- "Sandwich"
   Call <- match.call()
   fm <- formula
   
-  if (is.null(weight)) {
-    weight <- rep(1,nrow(data[!duplicated(data$ID),]))
-  } 
+  #if (is.null(weight)) {
+  #  weight <- rep(1,nrow(data[!duplicated(data[,colnames(data)==formula[[2]]$ID]),]))
+  #} 
   
   # A PanelSurv object
   obj <- eval(formula[[2]], data)
@@ -56,10 +56,16 @@ aeefit <- function(formula, data, weight=NULL, control=list()) {
     stdErr <- do.call("new", c(list(Class=se), stdErr.control))
   #}
   
-  
+  if(se=="Sandwich"){
   fit <- doPanelFit.AEE.Sandwich(DF=DF, panelMatrix=obj$panelMatrix, timeGrid=obj$timeGrid,
                                  X=X, engine=engine,weight=weight)
-  
+  }
+    
+  if(se=="Bootstrap"){
+      fit <- doPanelFit.AEE.Bootstrap(DF=DF, panelMatrix=obj$panelMatrix, timeGrid=obj$timeGrid,
+                                     X=X, engine=engine,weight=weight, boot)
+  }  
+    
   ret = list(formula=fm, beta=fit$beta, 
         baseline=fit$baseline,
         timeGrid=fit$timeGrid,
@@ -73,5 +79,4 @@ aeefit <- function(formula, data, weight=NULL, control=list()) {
   class(ret) <- "aeefit"
   ret
   
-}
-
+}
\ No newline at end of file
